'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

exports.default = function (babel) {
  var t = babel.types;


  return {
    visitor: {
      Program: function Program(path, state) {
        var modules = state.opts.modules || [];
        Object.values(path.scope.bindings).filter(function (binding) {
          return t.isImportDefaultSpecifier(binding.path) || t.isImportNamespaceSpecifier(binding.path) || t.isImportSpecifier(binding.path);
        }).filter(function (binding) {
          var p = binding.path.findParent(function (parentPath) {
            return parentPath.isImportDeclaration();
          });
          return modules.indexOf(p.node.source.value) >= 0;
        }).forEach(function (binding) {
          removeBinding(t, binding);
        });
      }
    }
  };
};

var leftCommentPattern = /\/\*/g;
var rightCommentPattern = /\*\//g;
var getComment = function getComment(input) {
  var source = input.replace(leftCommentPattern, '\\/*').replace(rightCommentPattern, '*\\/');
  if (source.indexOf('\n') < 0) return ' ' + source + ' ';
  return '*\n' + source.split('\n').map(function (line) {
    return ' * ' + line;
  }).join('\n') + '\n ';
};

function removeBinding(t, binding) {
  var shouldRemoveFunctionCalls = arguments.length <= 2 || arguments[2] === undefined ? true : arguments[2];

  if (!binding) return;
  var paths = binding.referencePaths;
  paths.forEach(function (path) {
    var parentPath = path.findParent(function (p) {
      return p.isExpressionStatement() || p.isVariableDeclaration() || p.isReturnStatement();
    });
    if (!parentPath) return;
    if (parentPath.isExpressionStatement()) {
      if (!shouldRemoveFunctionCalls && parentPath.node.expression.callee === path.node) {
        return;
      }
    } else if (parentPath.isVariableDeclaration()) {
      parentPath.traverse({
        VariableDeclarator: function VariableDeclarator(p) {
          removeBinding(t, parentPath.scope.bindings[p.node.id.name]);
        }
      });
    } else {
      var funcPath = parentPath.findParent(function (p) {
        return p.isFunctionDeclaration();
      });
      var name = funcPath.node.id.name;
      removeBinding(t, funcPath.parentPath.scope.bindings[name], false);
    }
    parentPath.addComment('trailing', getComment(parentPath.getSource()));
    parentPath.replaceWith(t.noop());
  });
}